@@ -1,6 +1,6 @@
 ## ---- echo = FALSE, results = "hide", message = FALSE--------------------
 require("emmeans")
-knitr::opts_chunk$set(collapse = TRUE, fig.width = 4.5)
+knitr::opts_chunk$set(fig.width = 4.5, class.output = "ro")
 
 ## ------------------------------------------------------------------------
 pigs.lm <- lm(log(conc) ~ source + factor(percent), data = pigs)
@@ -46,6 +46,11 @@ confint(pigs.rg, by = "source")
 #  emmeans(pigs.lm, ~ percent | source)     ### same results as above
 #  summary(.Last.value, by = percent)       ### grouped the other way
 
+## ------------------------------------------------------------------------
+pigsint.lm <- lm(log(conc) ~ source * factor(percent), data = pigs)
+pigsint.rg <- ref_grid(pigsint.lm)
+contrast(pigsint.rg, "consec", simple = "percent")
+
 ## ------------------------------------------------------------------------
 pigs.prs.s <- pairs(pigs.emm.s)
 pigs.prs.s
@@ -53,6 +58,9 @@ pigs.prs.s
 ## ------------------------------------------------------------------------
 test(pigs.prs.s, joint = TRUE)
 
+## ------------------------------------------------------------------------
+joint_tests(pigsint.rg)
+
 ## ------------------------------------------------------------------------
 test(pigs.prs.s, delta = log(1.25), adjust = "none")
 
